# Network

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**data_center_id** | **str** |  | 
**ip_range** | **str** |  | 
**gateway** | **str** |  | 
**size** | [**V1VRouterSize**](V1VRouterSize.md) |  | 
**price_hr** | [**Decimal**](Decimal.md) |  | 
**external_ip_address** | **str** |  | 
**internal_ip_address** | **str** |  | 
**short_state** | **str** |  | 
**state** | [**NetworkState**](NetworkState.md) |  | 
**create_time** | **datetime** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


